@@ -27,6 +27,7 @@
 #include <zlib.h>
 #include <cstdio>
 #include <libxml/tree.h>
+#include <map>
 class TrackList;
 class Track;
 class TrackListLoader
@@ -43,15 +44,19 @@ class TrackListLoader
 
         void load(Glib::ustring url, TrackList *track_list, sigc::slot<void,TrackList*> success_slot, sigc::slot<void> failure_slot);
 
-        void check_album_license(guint32 album_id, sigc::slot<void, guint32, Glib::ustring> success_slot, sigc::slot<void,guint32> failure_slot);
+        void check_album_license(guint32 album_id, sigc::slot<void, guint32, Glib::ustring, Glib::RefPtr<Gdk::Pixbuf>, double> success_slot, sigc::slot<void,guint32> failure_slot);
+
     protected:
     private:
         TrackList *d_track_list;
         Glib::RefPtr<Soup::Session> web;
+        std::map<Glib::ustring, Glib::RefPtr<Gdk::Pixbuf> > license_images;
 
         //callbacks
         void on_file_downloaded(Glib::RefPtr < Soup::Message > &msg, sigc::slot<void,TrackList*> success, sigc::slot<void> failure);
-        void on_album_info_downloaded(Glib::RefPtr < Soup::Message > &msg, guint32 album_id, sigc::slot<void,guint32, Glib::ustring> success, sigc::slot<void,guint32> failure);
+        void on_album_info_downloaded(Glib::RefPtr < Soup::Message > &msg, guint32 album_id, sigc::slot<void,guint32, Glib::ustring, Glib::RefPtr<Gdk::Pixbuf>, double> success, sigc::slot<void,guint32> failure);
+
+        void on_license_image_downloaded(Glib::RefPtr < Soup::Message > &msg, guint32 album_id, Glib::ustring license, double rating, sigc::slot<void,guint32, Glib::ustring, Glib::RefPtr<Gdk::Pixbuf>, double> success, sigc::slot<void,guint32> failure);
 
         //helpers
         TrackList* load_data(const char *data, guint len);
@@ -60,7 +65,7 @@ class TrackListLoader
         void parse_artists(xmlNodePtr child, std::map<guint32, Glib::ustring>& d_artists, std::map<guint32, Glib::ustring> &d_genre);
         TrackList* parse(char *data, size_t len);
 
-        bool get_license(const char *data, size_t len, Glib::ustring &license);
+        bool get_license_and_rating(const char *data, size_t len, Glib::ustring &license, double &rating);
 };
 
 #endif // TRACK_LIST_LOADER_H
