@@ -22,7 +22,7 @@ class Track
 {
     public:
 
-        Track(guint32 duration, Glib::ustring genre, Glib::ustring song_title, Glib::ustring artist_name, guint32 album_id, guint32 track_id, Glib::ustring license = "");
+        Track(guint32 duration, Glib::ustring genre, Glib::ustring song_title, Glib::ustring artist_name, guint32 album_id, guint32 track_id, Glib::ustring license = "", double rating = 0.0);
 
 	//! Copy constructor.
         Track(const Track&);
@@ -35,6 +35,8 @@ class Track
         guint32 get_track_id() const {return d_track_id;};
         Glib::ustring get_license() const {return d_license;};
         void set_license(Glib::ustring l) {d_license = l;};
+        double get_album_rating() const {return d_rating;};
+        void set_album_rating(double rating) {d_rating= rating;};
 
 	//! Destructor.
         ~Track();
@@ -48,6 +50,7 @@ class Track
         guint32 d_album_id;
         guint32 d_track_id;
         Glib::ustring d_license;
+        double d_rating;
 
 };
 
